@@ -594,6 +594,21 @@ class TeleBot:
             apihelper.send_video_note(self.token, chat_id, data, duration, length, reply_to_message_id, reply_markup,
                                       disable_notification, timeout))
 
+    def send_media_group(self, chat_id, media, disable_notification=None, reply_to_message_id=None):
+        """
+        send a group of photos or videos as an album. On success, an array of the sent Messages is returned.
+        :param chat_id:
+        :param media:
+        :param disable_notification:
+        :param reply_to_message_id:
+        :return:
+        """
+        result = apihelper.send_media_group(self.token, chat_id, media, disable_notification, reply_to_message_id)
+        ret = []
+        for msg in result:
+            ret.append(types.Message.de_json(msg))
+        return ret
+
     def send_location(self, chat_id, latitude, longitude, live_period=None, reply_to_message_id=None, reply_markup=None,
                       disable_notification=None):
         """
@@ -607,7 +622,8 @@ class TeleBot:
         :return: API reply.
         """
         return types.Message.de_json(
-            apihelper.send_location(self.token, chat_id, latitude, longitude, live_period, reply_to_message_id, reply_markup,
+            apihelper.send_location(self.token, chat_id, latitude, longitude, live_period, reply_to_message_id,
+                                    reply_markup,
                                     disable_notification))
 
     def edit_message_live_location(self, latitude, longitude, chat_id=None, message_id=None,
@@ -623,7 +639,7 @@ class TeleBot:
         :return:
         """
         return types.Message.de_json(
-            apihelper.edit_message_live_location(self, latitude, longitude, chat_id, message_id,
+            apihelper.edit_message_live_location(self.token, latitude, longitude, chat_id, message_id,
                                                  inline_message_id, reply_markup))
 
     def stop_message_live_location(self, chat_id=None, message_id=None, inline_message_id=None, reply_markup=None):
@@ -637,7 +653,7 @@ class TeleBot:
         :return:
         """
         return types.Message.de_json(
-            apihelper.stop_message_live_location(self, chat_id, message_id, inline_message_id, reply_markup))
+            apihelper.stop_message_live_location(self.token, chat_id, message_id, inline_message_id, reply_markup))
 
     def send_venue(self, chat_id, latitude, longitude, title, address, foursquare_id=None, disable_notification=None,
                    reply_to_message_id=None, reply_markup=None):
@@ -873,12 +889,12 @@ class TeleBot:
                      start_parameter, photo_url=None, photo_size=None, photo_width=None, photo_height=None,
                      need_name=None, need_phone_number=None, need_email=None, need_shipping_address=None,
                      is_flexible=None,
-                     disable_notification=None, reply_to_message_id=None, reply_markup=None):
+                     disable_notification=None, reply_to_message_id=None, reply_markup=None, provider_data=None):
         result = apihelper.send_invoice(self.token, chat_id, title, description, invoice_payload, provider_token,
                                         currency, prices, start_parameter, photo_url, photo_size, photo_width,
                                         photo_height,
                                         need_name, need_phone_number, need_email, need_shipping_address, is_flexible,
-                                        disable_notification, reply_to_message_id, reply_markup)
+                                        disable_notification, reply_to_message_id, reply_markup, provider_data)
         return types.Message.de_json(result)
 
     def answer_shipping_query(self, shipping_query_id, ok, shipping_options=None, error_message=None):
@@ -980,7 +996,7 @@ class TeleBot:
         return apihelper.create_new_sticker_set(self.token, user_id, name, title, png_sticker, emojis, contains_masks,
                                                 mask_position)
 
-    def add_sticker_to_set(self, user_id, name, png_sticker, emojis, mask_position):
+    def add_sticker_to_set(self, user_id, name, png_sticker, emojis, mask_position=None):
         """
         Use this method to add a new sticker to a set created by the bot. Returns True on success.
         :param user_id:
@@ -1054,7 +1070,7 @@ class TeleBot:
             self.pre_message_subscribers_next_step[chat_id].append(callback)
         else:
             self.pre_message_subscribers_next_step[chat_id] = [callback]
-            
+
     def clear_step_handler(self, message):
         """
         Clears all callback functions registered by register_next_step_handler().
@@ -1356,6 +1372,10 @@ class AsyncTeleBot(TeleBot):
     def send_video_note(self, *args, **kwargs):
         return TeleBot.send_video_note(self, *args, **kwargs)
 
+    @util.async()
+    def send_media_group(self, *args, **kwargs):
+        return TeleBot.send_media_group(self, *args, **kwargs)
+
     @util.async()
     def send_location(self, *args, **kwargs):
         return TeleBot.send_location(self, *args, **kwargs)
