@@ -274,6 +274,8 @@ class Message(JsonDeserializable):
             opts['reply_to_message'] = Message.de_json(obj['reply_to_message'])
         if 'edit_date' in obj:
             opts['edit_date'] = obj.get('edit_date')
+        if 'media_group_id' in obj:
+            opts['media_group_id'] = obj.get('media_group_id')
         if 'author_signature' in obj:
             opts['author_signature'] = obj.get('author_signature')
         if 'text' in obj:
@@ -333,22 +335,31 @@ class Message(JsonDeserializable):
             content_type = 'left_chat_member'
         if 'new_chat_title' in obj:
             opts['new_chat_title'] = obj['new_chat_title']
+            content_type = 'new_chat_title'
         if 'new_chat_photo' in obj:
             opts['new_chat_photo'] = Message.parse_photo(obj['new_chat_photo'])
+            content_type = 'new_chat_photo'
         if 'delete_chat_photo' in obj:
             opts['delete_chat_photo'] = obj['delete_chat_photo']
+            content_type = 'delete_chat_photo'
         if 'group_chat_created' in obj:
             opts['group_chat_created'] = obj['group_chat_created']
+            content_type = 'group_chat_created'
         if 'supergroup_chat_created' in obj:
             opts['supergroup_chat_created'] = obj['supergroup_chat_created']
+            content_type = 'supergroup_chat_created'
         if 'channel_chat_created' in obj:
             opts['channel_chat_created'] = obj['channel_chat_created']
+            content_type = 'channel_chat_created'
         if 'migrate_to_chat_id' in obj:
             opts['migrate_to_chat_id'] = obj['migrate_to_chat_id']
+            content_type = 'migrate_to_chat_id'
         if 'migrate_from_chat_id' in obj:
             opts['migrate_from_chat_id'] = obj['migrate_from_chat_id']
+            content_type = 'migrate_from_chat_id'
         if 'pinned_message' in obj:
             opts['pinned_message'] = Message.de_json(obj['pinned_message'])
+            content_type = 'pinned_message'
         if 'invoice' in obj:
             opts['invoice'] = Invoice.de_json(obj['invoice'])
             content_type = 'invoice'
@@ -389,6 +400,7 @@ class Message(JsonDeserializable):
         self.forward_date = None
         self.reply_to_message = None
         self.edit_date = None
+        self.media_group_id = None
         self.author_signature = None
         self.text = None
         self.entities = None
@@ -1959,3 +1971,45 @@ class MaskPosition(JsonDeserializable, JsonSerializable):
     def to_dic(self):
         return {'point': self.point, 'x_shift': self.x_shift, 'y_shift': self.y_shift, 'scale': self.scale}
 
+
+# InputMedia
+
+class InputMediaPhoto(JsonSerializable):
+    def __init__(self, media, caption=None):
+        self.type = "photo"
+        self.media = media
+        self.caption = caption
+
+    def to_json(self):
+        return json.dumps(self.to_dic())
+
+    def to_dic(self):
+        ret = {'type': self.type, 'media': self.media}
+        if self.caption:
+            ret['caption'] = self.caption
+        return ret
+
+
+class InputMediaVideo(JsonSerializable):
+    def __init__(self, media, caption=None, width=None, height=None, duration=None):
+        self.type = "video"
+        self.media = media
+        self.caption = caption
+        self.width = width
+        self.height = height
+        self.duration = duration
+
+    def to_json(self):
+        return json.dumps(self.to_dic())
+
+    def to_dic(self):
+        ret = {'type': self.type, 'media': self.media}
+        if self.caption:
+            ret['caption'] = self.caption
+        if self.width:
+            ret['width'] = self.width
+        if self.height:
+            ret['height'] = self.height
+        if self.duration:
+            ret['duration'] = self.duration
+        return ret
